# !/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Pro数据接口 
Created on 2017/07/01
@author: polo,Jimmy
@group : tushare.pro
"""

import simplejson as json
from functools import partial
import requests


class DataApi:

    __token = ''
    __http_url = 'http://54.169.163.141:8099/api/jeecg-boot/dataapi/'

    def __init__(self, token, timeout=10):
        """
        Parameters
        ----------
        token: str
            API接口TOKEN，用于用户认证
        """
        self.__token = token
        self.__timeout = timeout

    def query(self, api_name, fields='', **kwargs):
        # req_params = {
        #     'apiToken': self.__token,
        #     'params': kwargs,
        #     'fields': fields
        # }


        # formData = {'apiToken': self.__token, 'pageSize': kwargs['pageSize'], 'pageNo': kwargs['pageNo']}
        kwargs['apiKey'] = self.__token
        formData = kwargs

        res = requests.post(self.__http_url + api_name, data=formData, timeout=self.__timeout, headers={'X-Access-Token':''})
        result = json.loads(res.text)
        if result['code'] != 0:
            raise Exception(result['message'])
        data = result['result']
        # columns = fields
        # items = data['items']

        # return pd.DataFrame(items, columns=columns)
        print(data)
        return data

    def __getattr__(self, name):
        return partial(self.query, name)



# -*- coding:utf-8 -*- 
"""
pro init 
Created on 2022/08/10
@author: gmcheng
@group : blueonion.dataapi
@contact: jimmysoa@sina.cn
"""
from blueonion.dataapi import client

PRICE_COLS = ['open', 'close', 'high', 'low', 'pre_close']
FORMAT = lambda x: '%.2f' % x
FREQS = {'D': '1DAY',
         'W': '1WEEK',
         'Y': '1YEAR',
         }


def pro_api(token=''):
    """
    初始化pro API,第一次可以通过ts.set_token('your token')来记录自己的token凭证，临时token可以通过本参数传入
    """
    pro = client.DataApi(token)
    return pro


# -*- coding:utf-8 -*- 
import codecs
import os

__version__ = codecs.open(os.path.join(os.path.dirname(__file__), 'VERSION.txt')).read()
__author__ = 'gmcheng'

"""
for blueonion pro api
"""
from blueonion.dataapi.data_pro import (pro_api)
